@@ -1,4 +1,5 @@
 import inspect
+import asyncio
 from typing import Any, Awaitable, Callable, Optional, TypeVar, Generic, Union
 
 from mediatr.exceptions import raise_if_handler_not_found, raise_if_request_none, raise_if_handler_is_invalid, raise_if_validator_is_invalid
@@ -87,12 +88,14 @@ class Mediator():
         handler_func = None
         validator_func = None
         handler_obj = None
+        validator_obj = None
 
         handler_obj = self1.handler_class_manager(handler)
         handler_func = handler_obj.handle
 
         if validator:
-            validator_func = handler_obj.validate
+            validator_obj = self1.handler_class_manager(validator)
+            validator_func = validator_obj.validate
             validator_result = asyncio.create_task(validator_func(request))
             await validator_result
 
